@@ -1,4 +1,4 @@
-from request_signer.tests.auth_signer_tests import *
+from request_signer.tests.signer_tests import *
 from request_signer.tests.signed_request_tests import *
 from request_signer.tests.response_tests import *
 from request_signer.tests.request_tests import *
